Crate futhorc[][src]

Modules

build
config

Contains the logic for collecting and consolidating the program’s configuration.

htmlrenderer
post

The post module defines the Post, Parser, and Error types. It defines the logic for parsing posts from the file system into memory. See the Post::to_value and Post::summarize for details on how posts are converted into template values.

tag
url
value
write

Takes Post objects created by the [post] module and turns them into index and post HTML files on the file system.